Module attested

Module attested 

Structs

Attested
A wrapper struct for holding a message and it’s attestation.
DcapAttestation
A verifiable DCAP attestation generated by an enclave.
MockAttestation
Noop
RawAttested
RawDcapAttestation
RawMockAttestation
RawNoop

Traits

Attestation
HasUserData
A trait that defines how to extract user data from a given type.

Functions

user_data_json

Type Aliases

DefaultAttestation
Quote
Alias for an owned DCAP quote. This is the main part of a DCAP attestation generated by an enclave that we want to verify on-chain.
RawDefaultAttestation