Structs
- Attested
- A wrapper struct for holding a message and it’s attestation.
- Dcap
Attestation - A verifiable DCAP attestation generated by an enclave.
- Mock
Attestation - Noop
- RawAttested
- RawDcap
Attestation - RawMock
Attestation - RawNoop
Traits
- Attestation
- HasUser
Data - A trait that defines how to extract user data from a given type.
Functions
Type Aliases
- Default
Attestation - Quote
- Alias for an owned DCAP quote. This is the main part of a DCAP attestation generated by an enclave that we want to verify on-chain.
- RawDefault
Attestation